<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms_MY" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>There&apos;s life outside the browser!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versi %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Dilesenkan kepada: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 merupakan Perisian Bebas tetapi pembangunannya mengambil masa yang berharga.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Sila &lt;a href=&apos;%1&apos;&gt;beri sumbangan&lt;/a&gt; untuk menyokong pembangunan berterusan %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Terjemah %1 kepada bahasa ibunda anda menggunakan %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>Diperkasakan oleh %1</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>Perisian sumber-terbuka</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikon direka oleh %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Dikeluarkan dibawah &lt;a href=&apos;%1&apos;&gt;Lesen Awam Am GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>%Tutup</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Perihal</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Masukkan Perincian Lesen anda</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Emel:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kod:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Sila lesenkan %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Demo ini telah tamat tempoh.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Versi penuh membolehkan anda tonton video tanpa gangguan.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Tanpa lesen, aplikasi akan luput dalam tempoh %1 hari.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Dengan pembelian versi penuh, anda akan menyokong hasil kerja yang saya lakukan ketika menghasilkan %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Guna Demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Masukkan Lesen</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Beli Lesen</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Muat Turun</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Oleh %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>Anda mempunyai %n video baharu</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Semua Video</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Video Tidak Ditonton</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Terakhir Dikemaskini</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Terakhir Ditambah</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Terakhir Ditonton</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Paling Banyak Ditonton</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Isih mengikut</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Tanda semua sebagai ditonton</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Papar Dikemaskini</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Anda tidak mempunyai langganan. Gunakan simbol bintang untuk melanggan saluran.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Semua Video</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Video Tidak Ditonton</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Tanda sebagai Ditonton</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Nyahlanggan</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Tiada langganan dikemaskini buat masa ini.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Baru masuk</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>%n jam yang lalu</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation><numerusform>%n hari yang lalu</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation><numerusform>%n bulan yang lalu</numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>K</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>M</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>ditonton %1 kali</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation><numerusform>%n minggu yang lalu</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bait</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bait/saat</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/saat</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/saat</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>saat</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minit</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 berbaki</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 dimuat turun dalam %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Muat turun selesai</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation><numerusform>%n Muat Turun</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Ubah lokasi...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Pilih lokasi muat turun</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Lokasi muat turun berubah.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Muat turun semasa masih lagi berjalan pada lokasi terdahulu.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Memuat turun ke: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Muat turun</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Fail bolehlaku telah diusik, mungkin berpunca dari virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 tidak akan dijalankan. Cuba memasang sekali lagi.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Pasang semula</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Main</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Jeda</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Main/Jeda</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Henti</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Henti main selepas trek semasa</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Trek berikutnya</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Trek terdahulu</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Tingkatkan volum</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Rendahkan volum</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Senyap</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Jangkau kehadapan</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Jangkau mengundur</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Cari video dan saluran mengikut kata kunci</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Layar</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Layar video mengikut kategori</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Langganan</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Langganan saluran</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Sila guna mengikut keselesaan anda</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Tetingkap</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimum</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Henti</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Henti main balik dan kembali ke paparan gelintar</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Te&amp;rdahulu</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Pergi kembali ke trek terdahulu</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Lang&amp;kau</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Langkau ke video berikutnya</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Main</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Sambung semula main balik</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Skrin &amp;Penuh</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Pergi ke skrin penuh</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Mod Pa&amp;dat</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Sembunyi senarai main dan palang alat</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Buka Halaman &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Pergi ke halaman video YouTube dan jedakan main balik</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Salin Pa&amp;utan YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Salin pautan YouTube semasa ke papan keratan</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Salin &amp;URL Strim Video</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Salin URL strim video semasa ke papan keratan</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Cari Ba&amp;hagian Video</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Cari bahagian video lain yang diharapkan dalam tertib yang betul</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Buang</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Buang video terpilih dari senarai main</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Alih Ke &amp;Atas</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Alih video terpilih ke atas di dalam senarai main</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Alih Ke &amp;Bawah</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Alih video terpilih ke bawah dalam senarai main</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>K&amp;osongkan Gelintar Baru-baru Ini</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Kosongkan sejarah gelintar. Tidak dapat patah balik.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Keluar</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Selamat Tinggal</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Laman Sesa&amp;wang</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 pada Sesawang</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Beri S&amp;umbangan</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Sila beri sokongan pada pembangunan berterusan %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Perih&amp;al</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Maklumat mengenai %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Senyapkan volum</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Mula Main Secara &amp;Manual</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Mula memainkan video secara manual</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>Muat T&amp;urun</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Papar perincian mengenai muat turun video</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>Muat T&amp;urun</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Muat turun video semasa</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Ambil &amp;Cekupan Skrin</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Langgan ke Saluran</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Kongsi video semasa menggunakan %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Emel</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Emel</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Tutup</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>Te&amp;rapung Diatas</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Henti Selepas Video Ini</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Laporkan Masalah...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>Pe&amp;rhalusi Gelintar...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Lagi...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Video Be&amp;rkaitan</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Tonton video berkaitan dengan video semasa</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Buka dalam Pela&amp;yar...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Mod Terhad</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Sembunyi video yang mengandungi kandungan tidak senonoh</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>Togol Palang &amp;Menu</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Suka %1? Beri penarafan!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Beli %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplikasi</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Main Balik</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Se&amp;narai Main</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>K&amp;ongsi</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Papar</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Bantuan</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Tekan %1 untuk tingkatkan volum, %2 untuk rendahkannya</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Pilih lokasi kandungan anda</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Membuka %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Anda hendak keluar dari %1 dengan muat turun masih berjalan?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Jika anda tutup %1 sekarang, muat turun ini akan dibatalkan.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Tutup dan batalkan muat turun</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Tunggu sehingga muat turun selesai</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Ralat: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Jeda</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Jeda main balik</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Memuatkan...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Tinggalkan Skrin P&amp;enuh</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Masa berbaki: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volum pada %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volum disenyapkan</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volum disuarakan</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Definasi video maksimum ditetapkan ke %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Kerahsiaan anda kini selamat</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Muat turun selesai</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versi %2 kini sudah tersedia.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Maklum saya kemudian</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Kemaskini</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>Anda masih boleh mencapai palang menu dengan menekan kekunci ALT</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Anda kini boleh menampal pautan YouTube ke dalam aplikasi lain</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Anda kini boleh menampal pautan strim video ke dalam aplikasi lain</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Pautan hanya sah untuk masa yang terhad.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Memuat turun %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>dari</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>bahagian</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episod</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Dihantar daripada %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Buang langganan dari %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Langgan ke %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>Beralih ke %1</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Nyahlanggan daripada %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Langgan kepada %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Versi baru %1 tersedia!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 kini tersedia. Anda mempunyai %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Anda hendak muat turun ia sekarang?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Langkau Versi Ini</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Maklum Saya Kemudian</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Pasang Kemaskini</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Tampal</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>Pilih satu video</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 daripada %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Menyediakan</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Gagal</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Selesai</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Dihentikan</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Henti memuat turun</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Papar dalam %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Buka folder induk</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Mulakan semula memuat turun</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Papar %1 Lagi</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Tiada video</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Tiada lagi video</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Isih mengikut</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Kaitan</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Tarikh</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Kiraan Papar</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Penarafan</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Bila-bila Masa</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hari Ini</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 Hari</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 Hari</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Jangkamasa</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Semua</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Pendek</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Sederhana</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Panjang</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Kurang dari 4 minit</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Diantara 4 hingga 20 minit</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Lebih panjang dari 20 minit</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kualiti</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Definasi Tinggi</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p atau lebih tinggi</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Selesai</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Selesai</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Selamat datang ke &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>untuk menonton video.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>kata kunci</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Masukkan</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Kata kunci baru-baru ini</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Saluran baru-baru ini</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Dapatkan versi penuh</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Undur</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Maju</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Maju ke %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Undur ke %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Perhalusi Gelintar</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Adakah anda maksudkan: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Ubah lokasi...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Cekupan skrin disimpan ke dalam %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Lokasi cekupan skrin berubah.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Paling Popular</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Memuat turun kemaskini...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Memuat turun %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algeria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgium</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Canada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Republik Czech</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Mesir</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Perancis</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Jerman</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Yunani</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hungary</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Ireland</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Itali</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Jepun</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordan</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malaysia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexico</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Maghribi</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Belanda</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>New Zealand</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipina</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Poland</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusia</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Arab Saudi</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapura</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Afrika Selatan</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Korea Selatan</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Sepanyol</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Sweden</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisia</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turki</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Emiriah Arab Bersatu</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>United Kingdom</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Yaman</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Seluruh Dunia</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Tidak dapat strim video untuk %1</translation>
    </message>
</context>
</TS>